stable_model_list = [
    "runwayml/stable-diffusion-v1-5",
    "stabilityai/stable-diffusion-2-1",
]

controlnet_canny_model_list = [
    "lllyasviel/sd-controlnet-canny",
    "thibaud/controlnet-sd21-canny-diffusers",
]

controlnet_depth_model_list = [
    "lllyasviel/sd-controlnet-depth",
    "thibaud/controlnet-sd21-depth-diffusers",
]

controlnet_pose_model_list = [
    "lllyasviel/sd-controlnet-openpose",
    "thibaud/controlnet-sd21-openpose-diffusers",
]

controlnet_hed_model_list = [
    "lllyasviel/sd-controlnet-hed",
    "thibaud/controlnet-sd21-hed-diffusers",
]

controlnet_scribble_model_list = [
    "lllyasviel/sd-controlnet-scribble",
    "thibaud/controlnet-sd21-scribble-diffusers",
]
stable_inpiant_model_list = [
    "stabilityai/stable-diffusion-2-inpainting",
    "runwayml/stable-diffusion-inpainting",
]
